Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(28)

Unified Diff: ash/shell.h

Issue 2194353002: mash: Migrate ScopedTargetRootWindow to //ash/common (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: similarity 40 Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/shell.h
diff --git a/ash/shell.h b/ash/shell.h
index 465e12e64a21ed7899ef51509e06e993a2a2b956..a5377574cbd0f1eb1fbb7743196797af3bb70b77 100644
--- a/ash/shell.h
+++ b/ash/shell.h
@@ -111,7 +111,6 @@ class ResizeShadowController;
class ResolutionNotificationController;
class RootWindowController;
class ScopedOverviewAnimationSettingsFactoryAura;
-class ScopedTargetRootWindow;
class ScreenAsh;
class ScreenOrientationController;
class ScreenshotController;
@@ -186,9 +185,10 @@ class ASH_EXPORT Shell : public SystemModalContainerEventFilterDelegate,
// Returns a root Window when used as a target when creating a new window.
// The root window of the active window is used in most cases, but can
// be overridden by using ScopedTargetRootWindow().
// If you want to get the root Window of the active window, just use
// |wm::GetActiveWindow()->GetRootWindow()|.
+ // TODO(jamescook): Rename to GetRootWindowForNewWindows.
static aura::Window* GetTargetRootWindow();
// Returns the id of the display::Display corresponding to the window returned
@@ -480,7 +480,7 @@ class ASH_EXPORT Shell : public SystemModalContainerEventFilterDelegate,
FRIEND_TEST_ALL_PREFIXES(WindowManagerTest, MouseEventCursors);
FRIEND_TEST_ALL_PREFIXES(WindowManagerTest, TransformActivate);
friend class RootWindowController;
- friend class ScopedTargetRootWindow;
+ friend class ScopedRootWindowForNewWindowsAura;
friend class test::ShellTestApi;
friend class shell::WindowWatcher;
@@ -186,9 +185,10 @@ class ASH_EXPORT Shell : public SystemModalContainerEventFilterDelegate,
// Returns a root Window when used as a target when creating a new window.
// The root window of the active window is used in most cases, but can
- // be overridden by using ScopedTargetRootWindow().
+ // be overridden by using ScopedRootWindowForNewWindows.
// If you want to get the root Window of the active window, just use
// |wm::GetActiveWindow()->GetRootWindow()|.

Powered by Google App Engine
This is Rietveld 408576698